@@ -1,4 +1,4 @@
-from constants.Constants import *
+from ecosizer_engine_package.constants.Constants import *
 from .Building import Building
 import numpy as np
 from scipy.stats import norm #lognorm
